TUI
===

toot includes a
[text-based user interface](https://en.wikipedia.org/wiki/Text-based_user_interface).
Start it by running `toot tui`.

## Demo

[![asciicast](https://asciinema.org/a/563459.svg)](https://asciinema.org/a/563459)

## Keyboard shortcuts

Pressing `H` will bring up the help screen where all keyboard shortcuts are
listed.

**Navigation**

* `Arrow keys` or `H/J/K/L` to move around and scroll content
* `PageUp` and `PageDown` to scroll content
* `Enter` or `Space` to activate buttons and menu options
* `Esc` or `Q` to go back, close overlays and menus

**General**

* `Q` - quit toot
* `G` - go to - switch timelines
* `P` - save/unsave (pin) current timeline
* `,` - refresh current timeline
* `H` - show this help

**Status**

These commands are applied to the currently focused status.

* `B` - Boost/unboost status
* `C` - Compose new status
* `F` - Favourite/unfavourite status
* `K` - Bookmark/unbookmark status
* `N` - Translate status if possible (toggle)
* `R` - Reply to current status
* `S` - Show text marked as sensitive
* `T` - Show status thread (replies)
* `L` - Show the status links
* `U` - Show the status data in JSON as received from the server
* `V` - Open status in default browser
* `Z` - Open status in scrollable popup window
